@@ -1,7 +1,8 @@
-/* $Aumix: aumix/src/common.c,v 1.9 2002/10/29 21:27:51 trevor Exp $
+/* $Aumix: aumix/src/common.c,v 1.23 2010/05/06 03:36:47 trevor Exp $
  *
  * aumix:  adjust audio mixer
- * copyright (c) 1993, 1996-2002 the authors--see AUTHORS file
+ * copyright (c) 1993, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2008
+ * the authors--see AUTHORS file
  *
  * This file is part of aumix.
  *
@@ -24,9 +25,9 @@
 #include "curses.h"
 #include "gpm-xterm.h"
 #endif				/* HAVE_CURSES */
-#if defined (HAVE_GTK) || defined (HAVE_GTK1)
+#if defined (HAVE_GTK)
 #include "gtk.h"
-#endif				/* HAVE_GTK || HAVE_GTK1 */
+#endif				/* HAVE_GTK */
 #include "interactive.h"
 
 FILE           *OpenDefaultFile(char *mode);
@@ -120,12 +121,17 @@ int             main(int argc, char *argv[])
 	int             setcolors = FALSE;
 #endif				/* HAVE_CURSES */
 	/* Internationalization */
-#ifdef HAVE_NLS
+#ifdef ENABLE_NLS
 	I18nInitialize();
-#endif				/* HAVE_NLS */
+#endif				/* ENABLE_NLS */
 
 	interactive = FALSE;
 
+#ifdef __linux__
+	if (access(device_filename, F_OK) != 0)
+		device_filename = "/dev/sound/mixer";
+#endif
+
 /* Get options from the command line.  Using numbers as options is deprecated,
    but we do it anyway because it makes sense for line1, line2 and line3.
  */
@@ -177,12 +183,12 @@ int             main(int argc, char *argv[])
 					ErrorExitWarn(InitializeMixer(device_filename), 'e');
 				ErrorExitWarn(LoadSettings(), 'e');
 				break;
-#if defined (HAVE_CURSES) || defined (HAVE_GTK) || defined (HAVE_GTK1)
+#if defined (HAVE_CURSES) || defined (HAVE_GTK)
 			case 'I':	/* User asked for interactive mode. */
 				if (!interactive)
 					interactive = IN_ANY;
 				break;
-#endif				/* HAVE_CURSES || HAVE_GTK || HAVE_GTK1 */
+#endif				/* HAVE_CURSES || HAVE_GTK */
 			case 'h':	/* Show help. */
 				Usage(EXIT_SUCCESS);
 				break;
@@ -191,7 +197,7 @@ int             main(int argc, char *argv[])
 			}
 		}
 	}
-#if defined (HAVE_CURSES) || defined (HAVE_GTK) || defined (HAVE_GTK1)
+#if defined (HAVE_CURSES) || defined (HAVE_GTK)
 /* Be interactive if no options were given. */
 	if (!interactive && argc <= 1)
 		interactive = IN_ANY;
@@ -199,26 +205,32 @@ int             main(int argc, char *argv[])
    The -C (color scheme) option implies curses, even if GTK is available.
 */
 	if (interactive == IN_ANY) {
-#if defined (HAVE_GTK) || defined (HAVE_GTK1)
-		if (getenv("DISPLAY") != NULL)
+#if defined (HAVE_GTK)
+		char *env_display;
+/* ignore DISPLAY if it is set, but empty */
+		if ((env_display = getenv("DISPLAY")) && (*env_display != '\0'))
 			interactive = IN_GTK;
-#endif				/* HAVE_GTK || HAVE_GTK1 */
+#endif				/* HAVE_GTK */
 #ifdef HAVE_CURSES
 		if (interactive == IN_ANY)
 			interactive = IN_CURSES;
 #endif				/* HAVE_CURSES */
 	}
-#endif				/* HAVE_CURSES || HAVE_GTK || HAVE_GTK1 */
+#endif				/* HAVE_CURSES || HAVE_GTK */
 /* By now, interactive is not IN_ANY.  It is IN_GTK only if DISPLAY is set,
    and otherwise defaults to IN_CURSES.  Since interactive contains the right
    value, it should not be changed any more.
 */
-#if defined (HAVE_GTK) || defined (HAVE_GTK1)
+#if defined (HAVE_GTK)
 /* GTK+ stuff */
 	if (interactive == IN_GTK) {
+#ifdef HAVE_GTK /* GTK+ 2.X only */
+/* Use UTF8 format even if the locale is non-UTF8. */
+		bind_textdomain_codeset (PACKAGE, "UTF-8");
+#endif
 #ifndef DUMMY_MIXER
 		if ((mixer_fd = open(device_filename, O_RDWR)) < 0)
-			return EOPENMIX;
+			ErrorExitWarn(EOPENMIX, 'e');
 #endif				/* DUMMY_MIXER */
 		ErrorExitWarn(MixerStatus(), 'e');
 		if (!devmask)
@@ -228,7 +240,7 @@ int             main(int argc, char *argv[])
 		gtk_main();
 		return 0;
 	}
-#endif				/* HAVE_GTK || HAVE_GTK1 */
+#endif				/* HAVE_GTK */
 	if (!interactive) {
 		if (usage_ok && optn == -1)
 			Usage(EXIT_SUCCESS);
@@ -264,14 +276,17 @@ void            ErrorExitWarn(int error, int mode)
 	if (!error)
 		return;
 #if HAVE_CURSES
-	if (mode == 'e')	/* exit */
+/* Only close screen for curses; GTK+ has not yet been initialized.
+   XXX Why the difference in program flow?
+*/
+	if ((mode == 'e') && (interactive == IN_CURSES))
 		CloseScreen();
 #endif				/* HAVE_CURSES */
 	if (error > 12) {
 		sprintf(string, LOCAL_TEXT("aumix:  unknown error %i"), error);
-		fprintf(stderr, string);
+		perror(string);
 	} else if (error > 0) {
-		fprintf(stderr, LOCAL_TEXT(errorlist[error - 1]));
+		perror(LOCAL_TEXT(errorlist[error - 1]));
 	}
 	fprintf(stderr, "\n");
 	if (mode == 'e')	/* exit */
@@ -591,7 +606,7 @@ FILE           *OpenDefaultFile(char *mode)
 	char            filename[PATH_MAX];
 	if (save_filename == NULL) {
 		home = getenv("HOME");
-		if ((strlen(home) + strlen(AUMIXRC) + 2) < PATH_MAX) {
+		if (home && ((strlen(home) + strlen(AUMIXRC) + 2) < PATH_MAX)) {
 			sprintf(filename, "%s/.%s", home, AUMIXRC);
 			setfile = CheckAndOpen(filename, mode);
 		}
@@ -612,17 +627,19 @@ FILE           *OpenDefaultFile(char *mode)
 int             SetShowNoninter(int dev)
 {
 /* Change or display settings from the command line. */
-	char           *devstr, dest;
+	char           *devstr;
+	char            dest[4];
 	int             change = 0, tmp, left, right;
 	/* Increase or decrease levels, optionally by a number. */
 	if (!strncmp(optarg, "+", 1) || !strncmp(optarg, "-", 1)) {
 		ErrorExitWarn(ReadLevel(dev, &tmp), 'e');
 		right = tmp >> 8;	/* I'll take the high byte, */
 		left = tmp & 0xFF;	/* and you take the low byte. */
-		strncpy(&dest, (optarg + 1), 3);
+		memset(dest, 0, sizeof(dest));
+		strncpy(dest, (optarg + 1), 3);
 		change = 1;	/* For compatibility with versions 1.15 to 1.17, assume one if no number was given. */
-		if (atoi(&dest))
-			change = atoi(&dest);
+		if (atoi(dest))
+			change = atoi(dest);
 		if (*optarg == '+') {	/* increase */
 			right += change;
 			left += change;
@@ -669,10 +686,10 @@ void            Usage(int status)
 /* These declarations are for embedding the copyright and version information in the binary for display by utilities such as what(1).  They needn't be translated. */
 	static char     version[] = "@(#) aumix " VERSION "\n";
 	static char     copyright[] =
-	"@(#) copyright (c) 1993, 1996-2000 the authors--see AUTHORS file\n";
+	"@(#) copyright (c) 1993, 1996-2010 the authors--see AUTHORS file\n";
 	fp = (status == EXIT_SUCCESS) ? stdout : stderr;
 	fprintf(fp, LOCAL_TEXT("aumix %s usage: aumix [-<channel option>[[+|-][<amount>]]|<level>|\nR[ecord]|P[lay]|q[uery]]"), VERSION);
-#if defined(HAVE_CURSES) || defined(HAVE_GTK) || defined(HAVE_GTK1)
+#if defined(HAVE_CURSES) || defined(HAVE_GTK)
 	fprintf(fp, LOCAL_TEXT(" [-dhILqS]"));
 #else
 	fprintf(fp, LOCAL_TEXT(" [-dhLqS]"));
@@ -703,10 +720,10 @@ other options:\n"));
   f:  specify file for saving and loading settings (defaults to\n\
       ~/.aumixrc or /etc/aumixrc)\n\
   h:  this helpful message\n"));
-#if defined(HAVE_CURSES) || defined(HAVE_GTK) || defined(HAVE_GTK1)
+#if defined(HAVE_CURSES) || defined(HAVE_GTK)
 	fprintf(fp, LOCAL_TEXT("\
   I:  start in interactive mode after doing non-interactive functions\n"));
-#endif				/* HAVE_CURSES || HAVE_GTK || HAVE_GTK1 */
+#endif				/* HAVE_CURSES || HAVE_GTK */
 	fprintf(fp, LOCAL_TEXT("\
   L:  load settings\n\
   q:  query all channels and print their settings\n\
@@ -719,15 +736,15 @@ other options:\n"));
 void            I18nInitialize(void)
 {
 	/*
-	 * If HAVE_NLS is defined, assume the existence of the three functions invoked here.
+	 * If ENABLE_NLS is defined, assume the existence of the three functions invoked here.
 	 */
-#ifdef HAVE_NLS
+#ifdef ENABLE_NLS
 	/* Set the current locale. */
 	setlocale(LC_ALL, "");
 	/* Set the text message domain. */
 	bindtextdomain((char *) PACKAGE, LOCALEDIR);
 	textdomain((char *) PACKAGE);
-#endif				/* HAVE_NLS */
+#endif				/* ENABLE_NLS */
 }
 #ifdef HAVE_ALSA
 /* Unmuting "hardware mute" in ALSA driver.  Currently unmuting is done only
