@@ -1,7 +1,7 @@
-/* $Aumix: aumix/src/curses.c,v 1.6 2002/10/23 15:07:40 trevor Exp $ */
+/* $Aumix: aumix/src/curses.c,v 1.19 2010/05/04 03:16:24 trevor Exp $ */
 /* curses.c:  functions specific to ncurses mode
- * copyright (c) 1993, 1996-2000, 2002 the authors--see AUTHORS file
- *
+ * copyright (c) 1993, 1996, 1997, 1998, 1999, 2000, 2002, 2004, 2005, 2010
+ * the authors--see AUTHORS file
  *
  * This file is part of aumix.
  *
@@ -26,9 +26,10 @@
 #include "interactive.h"
 #include "mouse.h"
 
-char           *chark, *charl, *charm, *charo, *charq, *chars, *charu, *lang;
+unsigned char  *key_keys, *key_load, *key_mute, *key_only, *key_quit, *key_save, *key_undo, *lang;
 int             current_dev, level_increment, balance_increment, menu_width, level_width, label_width, balance_width, levelbalmode, cols_saved, lines_saved;
 int             in_keysbox = FALSE;
+static int	cursor_x, cursor_y;	/* keep track of cursor position */
 
 void            InitScreenCurses(void)
 {
@@ -121,6 +122,8 @@ void            InitScreenCurses(void)
 	for (ii = 0; ii < SOUND_MIXER_NRDEVICES; ii++) {
 		if ((1 << ii) & (devmask | recmask)) {
 			attrset(COLOR_PAIR(AXIS_COLOR));
+/* fill the label area with spaces */
+			mvaddnstr(YOFFSET + y, XOFFSET + menu_width + R_P_WIDTH + level_width, "                 ", label_width + 2);
 			/* draw control labels */
 			mvaddstr(YOFFSET + y++, XOFFSET + menu_width + R_P_WIDTH + level_width + ARROW_WIDTH, LOCAL_TEXT(dev_label[ii]));
 		}
@@ -140,12 +143,20 @@ void            PlaceCursor(void)
 	refresh();
 	attrset(COLOR_PAIR(MENU_COLOR) | A_UNDERLINE);
 	mvaddch(0, 4, 'x');
+	/* Braille-friendly cursor positioning */
+	if (cursor_y >= 0) {
+		move(cursor_y, cursor_x);
+		leaveok(stdscr, FALSE);
+	}
 	refresh();
+	if (cursor_y >= 0) leaveok(stdscr, TRUE);
 }
 
 void            HighlightLabelCurses(void)
 {
 	attrset(COLOR_PAIR(ACTIVE_COLOR) | ((has_colors()) ? A_BOLD : A_REVERSE));
+/* fill the label area with spaces */
+	mvaddnstr(YOFFSET + CountChannels(current_dev), XOFFSET + menu_width + R_P_WIDTH + level_width + ARROW_WIDTH, "               ", label_width);
 	mvaddstr(YOFFSET + CountChannels(current_dev), XOFFSET + menu_width + R_P_WIDTH + level_width + ARROW_WIDTH, LOCAL_TEXT(dev_label[current_dev]));
 	PlaceCursor();
 }
@@ -271,6 +282,7 @@ int             InitColors(char *scheme)
 	int             bg, fg, ii;
 	if ((strlen(scheme) + strlen(DATADIR) + 1) >= PATH_MAX)
 		ErrorExitWarn(EFILE, 'e');
+	sprintf(filename, "%s", scheme);
 	schemefile = fopen(filename, "r");
 	if (schemefile == NULL) {
 		sprintf(filename, "%s/%s", DATADIR, scheme);
@@ -386,7 +398,8 @@ void            Inter(void)
 			DrawLevel(current_dev);
 			attrset(COLOR_PAIR(AXIS_COLOR));
 			y = CountChannels(current_dev);
-			mvaddstr(YOFFSET + y, XOFFSET + menu_width + R_P_WIDTH + level_width, "          ");
+/* fill the label area with spaces */
+			mvaddnstr(YOFFSET + y, XOFFSET + menu_width + R_P_WIDTH + level_width, "                 ", label_width + 2);
 			attrset(COLOR_PAIR(AXIS_COLOR));
 			mvaddstr(YOFFSET + y, XOFFSET + menu_width + R_P_WIDTH + level_width + ARROW_WIDTH, LOCAL_TEXT(dev_label[current_dev]));
 			/* switch to next existing device */
@@ -418,6 +431,7 @@ void            Inter(void)
 			else
 				AdjustLevel(current_dev, 0, 0);
 			break;
+		case '0':
 		case ']':
 			if ((levelbalmode) && ((1 << current_dev) & stereodevs))
 				AdjustBalance(current_dev, 0, MAXLEVEL);
@@ -460,19 +474,19 @@ void            Inter(void)
 			break;
 		}
 		key = tolower(key);
-		if (key == *chark) {
+		if (key == *key_keys) {
 			KeysBox();
-		} else if (key == *charl)
+		} else if (key == *key_load)
 			LoadSettings();
-		else if (key == *charm)
+		else if (key == *key_mute)
 			ToggleMuting();
-		else if (key == *charo)
+		else if (key == *key_only)
 			Muting(current_dev, MUTE_ONLY);
-		else if (key == *charq)
+		else if (key == *key_quit)
 			return;
-		else if (key == *chars)
+		else if (key == *key_save)
 			SaveSettings();
-		else if (key == *charu)
+		else if (key == *key_undo)
 			Muting(MUTE_NO_DEVICE, MUTE_OFF);
 		refresh();
 	}
@@ -487,8 +501,15 @@ void            DrawLevelBalModeCurses(int dev, int mode)
 	if ((1 << dev) & devmask) {
 		if ((mode) && ((1 << dev) & stereodevs)) {
 			mvaddch(YOFFSET + y, XOFFSET + menu_width + R_P_WIDTH + level_width + ARROW_WIDTH + label_width, '>');
+/* cursor placement for Braille consoles */
+			cursor_y = YOFFSET + y;
+			cursor_x = XOFFSET + menu_width + R_P_WIDTH + level_width + ARROW_WIDTH + label_width;
 		} else {
 			mvaddch(YOFFSET + y, XOFFSET + menu_width + R_P_WIDTH + level_width, '<');
+			attrset(COLOR_PAIR(AXIS_COLOR));
+  			mvaddch(YOFFSET + y, XOFFSET + menu_width + R_P_WIDTH + level_width + ARROW_WIDTH + label_width, ' '); /* erases ">" */
+			cursor_y = YOFFSET + y; /* for Braille */
+			cursor_x = XOFFSET + menu_width; /* for Braille */
 		}
 	}
 	PlaceCursor();
@@ -567,10 +588,10 @@ void            DrawRecordPlayCurses(int dev)
 void            CloseScreenCurses(void)
 {
 	if (interactive) {
-		initscr();	/* Calling refresh() will cause a segfault if we do it without initializing the screen. */
 		clear();
 		refresh();
 		endwin();
+		printf("\n"); /* resets color of cursor */
 	}
 }
 #endif				/* HAVE_CURSES */
