@@ -1,4 +1,4 @@
-/* $Aumix: aumix/src/gtk.c,v 1.8 2002/10/29 21:27:52 trevor Exp $
+/* $Aumix: aumix/src/gtk.c,v 1.11 2010/04/26 10:24:07 trevor Exp $
  *
  * gtk.c:  GTK+ interface for aumix
  * (c) 1998-2001 the authors (see AUTHORS file)
@@ -37,7 +37,7 @@
  */
 
 #include "common.h"
-#if defined (HAVE_GTK1) || defined (HAVE_GTK)
+#if defined (HAVE_GTK)
 #include "gtk.h"
 #include "../data/aumix.xpm"
 #include "record.xpm"
@@ -152,6 +152,28 @@ void            HideShowChannelGTK(int device)
 	visible[device] = !visible[device];
 }
 
+void            HideShowRecPlayGTK(void)
+{
+	int             ii;
+	recplayvisible = !recplayvisible;
+	if (recplayvisible) {
+		gtk_widget_show(labelrec);
+	} else {
+		gtk_widget_hide(labelrec);
+	}
+	for (ii = 0; ii < SOUND_MIXER_NRDEVICES; ii++) {
+		if (recplayvisible) {
+			/* Show the record/play button, if any. */
+			if ((1 << ii) & recmask)
+				gtk_widget_show(GTK_WIDGET(rpbuttons[ii]));
+		} else {
+			/* Hide the record/play button, if any. */
+			if ((1 << ii) & recmask)
+				gtk_widget_hide(GTK_WIDGET(rpbuttons[ii]));
+		}
+	}
+}
+
 void            AdjustLevelGTK(int device)
 {
 	AdjustLevel(device, 0, adjustment[device]->value);
@@ -175,14 +197,13 @@ void            InitScreenGTK(void)
 	GtkWidget      *filemenu;
 	GtkWidget      *filemenuitems[5];
 	GtkWidget      *viewmenu;
-	GtkWidget      *viewmenuitems[SOUND_MIXER_NRDEVICES + 3];
+	GtkWidget      *viewmenuitems[SOUND_MIXER_NRDEVICES + 4];
 	GtkWidget      *separator;
 	GtkWidget      *mutemenu;
 	GtkWidget      *muteallitem;
 	GtkWidget      *menubar;
 	GtkWidget      *menubarlabel;
 	GtkAccelGroup  *accel;
-	GtkWidget      *labelrec;
 	GtkWidget      *labellevel;
 	GtkWidget      *control_box;
 	int             balset, max, y, tmp, left, right;
@@ -190,8 +211,8 @@ void            InitScreenGTK(void)
 	GtkSignalFunc   filefuncs[] = {&LoadSettingsGTK, &SaveSettingsGTK, &LoadDialog, &SaveDialog, &CloseScreenGTK};
 	char           *filemenutext[] = {LOCAL_TEXT_NOOP("Load"), LOCAL_TEXT_NOOP("Save"), LOCAL_TEXT_NOOP("Load From"), LOCAL_TEXT_NOOP("Save To"), LOCAL_TEXT_NOOP("Quit")};
 	char           *fileacceltext[5] = {LOCAL_TEXT_NOOP("l"), LOCAL_TEXT_NOOP("s"), LOCAL_TEXT_NOOP("f"), LOCAL_TEXT_NOOP("t"), LOCAL_TEXT_NOOP("q")};
-	char           *viewmenutext[] = {LOCAL_TEXT_NOOP("Menu"), LOCAL_TEXT_NOOP("Balance"), LOCAL_TEXT_NOOP("Numbers")};
-	char           *viewacceltext[] = {LOCAL_TEXT_NOOP("v"), LOCAL_TEXT_NOOP("b"), LOCAL_TEXT_NOOP("n")};
+	char           *viewmenutext[] = {LOCAL_TEXT_NOOP("Menu"), LOCAL_TEXT_NOOP("Balance"), LOCAL_TEXT_NOOP("Record/Play"), LOCAL_TEXT_NOOP("Numbers")};
+	char           *viewacceltext[] = {LOCAL_TEXT_NOOP("v"), LOCAL_TEXT_NOOP("b"), LOCAL_TEXT_NOOP("r"), LOCAL_TEXT_NOOP("n")};
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(window), "aumix");
 	gtk_signal_connect(GTK_OBJECT(window), "destroy", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
@@ -200,11 +221,7 @@ void            InitScreenGTK(void)
 	gtk_widget_show(mainbox);
 	gtk_container_add(GTK_CONTAINER(window), mainbox);
 	accel = gtk_accel_group_new();
-#ifdef HAVE_GTK1
-	gtk_accel_group_attach(accel, GTK_OBJECT(window));
-#else
 	gtk_window_add_accel_group(GTK_WINDOW(window), accel);
-#endif
 	menubar = gtk_menu_bar_new();
 	gtk_widget_show(menubar);
 	gtk_box_pack_start(GTK_BOX(mainbox), menubar, FALSE, TRUE, 0);
@@ -232,22 +249,23 @@ void            InitScreenGTK(void)
 	gtk_menu_append(GTK_MENU(viewmenu), separator);
 	menuvisible = TRUE;
 	balancevisible = TRUE;
+	recplayvisible = TRUE;
 	valuesvisible = TRUE;
 	viewmenuitems[SOUND_MIXER_NRDEVICES] = gtk_check_menu_item_new_with_label(LOCAL_TEXT("Menu"));
 	viewmenuitems[SOUND_MIXER_NRDEVICES + 1] = gtk_check_menu_item_new_with_label(LOCAL_TEXT("Balance"));
-	viewmenuitems[SOUND_MIXER_NRDEVICES + 2] = gtk_check_menu_item_new_with_label(LOCAL_TEXT("Numbers"));
-	gtk_menu_append(GTK_MENU(viewmenu), viewmenuitems[SOUND_MIXER_NRDEVICES]);
-	gtk_menu_append(GTK_MENU(viewmenu), viewmenuitems[SOUND_MIXER_NRDEVICES + 1]);
-	gtk_menu_append(GTK_MENU(viewmenu), viewmenuitems[SOUND_MIXER_NRDEVICES + 2]);
+	viewmenuitems[SOUND_MIXER_NRDEVICES + 2] = gtk_check_menu_item_new_with_label(LOCAL_TEXT("Record/Play"));
+	viewmenuitems[SOUND_MIXER_NRDEVICES + 3] = gtk_check_menu_item_new_with_label(LOCAL_TEXT("Numbers"));
+	for (ii = 0; ii < 4; ii++) {
+		gtk_menu_append(GTK_MENU(viewmenu), viewmenuitems[SOUND_MIXER_NRDEVICES + ii]);
+	}
 	gtk_widget_add_accelerator(viewmenuitems[SOUND_MIXER_NRDEVICES], "activate", accel, *LOCAL_TEXT("v"), 0, GTK_ACCEL_VISIBLE);
 	gtk_widget_add_accelerator(viewmenuitems[SOUND_MIXER_NRDEVICES + 1], "activate", accel, *LOCAL_TEXT("b"), 0, GTK_ACCEL_VISIBLE);
-	gtk_widget_add_accelerator(viewmenuitems[SOUND_MIXER_NRDEVICES + 2], "activate", accel, *LOCAL_TEXT("n"), 0, GTK_ACCEL_VISIBLE);
-	gtk_widget_show(viewmenuitems[SOUND_MIXER_NRDEVICES]);
-	gtk_widget_show(viewmenuitems[SOUND_MIXER_NRDEVICES + 1]);
-	gtk_widget_show(viewmenuitems[SOUND_MIXER_NRDEVICES + 2]);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(viewmenuitems[SOUND_MIXER_NRDEVICES]), TRUE);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(viewmenuitems[SOUND_MIXER_NRDEVICES + 1]), TRUE);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(viewmenuitems[SOUND_MIXER_NRDEVICES + 2]), TRUE);
+	gtk_widget_add_accelerator(viewmenuitems[SOUND_MIXER_NRDEVICES + 2], "activate", accel, *LOCAL_TEXT("r"), 0, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator(viewmenuitems[SOUND_MIXER_NRDEVICES + 3], "activate", accel, *LOCAL_TEXT("n"), 0, GTK_ACCEL_VISIBLE);
+	for (ii = 0; ii < 4; ii++) {
+		gtk_widget_show(viewmenuitems[SOUND_MIXER_NRDEVICES + ii]);
+		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(viewmenuitems[SOUND_MIXER_NRDEVICES + ii]), TRUE);
+	}
 	muteallitem = gtk_check_menu_item_new_with_label(LOCAL_TEXT("Mute All"));
 	gtk_menu_append(GTK_MENU(mutemenu), muteallitem);
 /* XXX The "m" needs to get translated. */
@@ -328,7 +346,8 @@ void            InitScreenGTK(void)
 	}
 	gtk_signal_connect_object(GTK_OBJECT(viewmenuitems[SOUND_MIXER_NRDEVICES]), "activate", GTK_SIGNAL_FUNC(HideShowMenuGTK), GTK_OBJECT(menubar));
 	gtk_signal_connect_object(GTK_OBJECT(viewmenuitems[SOUND_MIXER_NRDEVICES + 1]), "activate", GTK_SIGNAL_FUNC(HideShowBalancesGTK), 0);
-	gtk_signal_connect_object(GTK_OBJECT(viewmenuitems[SOUND_MIXER_NRDEVICES + 2]), "activate", GTK_SIGNAL_FUNC(HideShowNumbersGTK), 0);
+	gtk_signal_connect_object(GTK_OBJECT(viewmenuitems[SOUND_MIXER_NRDEVICES + 2]), "activate", GTK_SIGNAL_FUNC(HideShowRecPlayGTK), 0);
+	gtk_signal_connect_object(GTK_OBJECT(viewmenuitems[SOUND_MIXER_NRDEVICES + 3]), "activate", GTK_SIGNAL_FUNC(HideShowNumbersGTK), 0);
 	control_box = gtk_hbox_new(FALSE, BORDER);
 	gtk_widget_show(control_box);
 	labelrec = gtk_label_new(LOCAL_TEXT("Rec"));
@@ -425,6 +444,7 @@ void            FileOKLoad(GtkWidget * w, GtkFileSelection * fs)
 /* Get the selected filename and copy it into the global save_filename. */
 {
 	save_filename = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
+	gtk_widget_destroy(fs);
 	ErrorExitWarn(LoadSettings(), 'w');
 }
 
@@ -432,6 +452,7 @@ void            FileOKSave(GtkWidget * w, GtkFileSelection * fs)
 /* Get the selected filename and copy it into the global save_filename. */
 {
 	save_filename = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
+	gtk_widget_destroy(fs);
 	ErrorExitWarn(SaveSettings(), 'e');
 }
 
@@ -464,4 +485,4 @@ void            SaveDialog(void)
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(filew), ".aumixrc");
 	gtk_widget_show(filew);
 }
-#endif				/* HAVE_GTK1 || HAVE_GTK */
+#endif				/* HAVE_GTK */
