@@ -1,3 +1,4 @@
+/* $Aumix: aumix/src/interactive.h,v 1.4 2010/04/24 05:58:35 trevor Exp $ */
 #ifndef INTERACTIVE_H
 #define INTERACTIVE_H
 #define MUTE_NO_DEVICE -1
@@ -6,7 +7,7 @@
 #define MUTE_ONLY 2
 #define        REFRESH_PERIOD 1	/* number of seconds between updates */
 
-char           *chark, *charl, *charm, *charo, *charq, *chars, *charu;
+unsigned char  *key_keys, *key_load, *key_mute, *key_only, *key_quit, *key_save, *key_undo;
 void            AumixSignalHandler(int signal_number);
 void            InitScreen(void);
 void            KeysBox(void);
